==> mzanalytics_mybmw-0.3.7.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';

import 'package:mzanalytics_mybmw/mzanalytics_mybmw.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _cid = 'Unknown';
  String _oaid = 'Unknown';
  String _myevent = '自定义事件';

  @override
  void initState() {
    super.initState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.

  void getcid() async {
    // callback function

    String cid = await MzanalyticsMybmw.getCid();

    setState(() {
      _cid = cid;
    });
  }

  @override
  Widget build(BuildContext context) {
    MzanalyticsMybmw.logEnabled(true);
    return MaterialApp(
      // navigatorObservers: [MZNavigationHistoryObserver()],
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Container(
          padding: EdgeInsets.all(10.0),
          child: Column(
            children: <Widget>[
              RaisedButton(
                key: Key("key1"),
                onPressed: () {
                  MzanalyticsMybmw.appid("2814");
                },
                child: Text('初始化'),
              ),
              RaisedButton(
                key: Key("key2"),
                onPressed: () {
                  MzanalyticsMybmw.trackPageView({
                    "dt": "首页",
                    "CustomDimMetrics": {
                      "cd1": "ID88888", //需统计的自定义维度1的名称，如浏览该页面的用户Id
                      "cd2": "小明机器人", //需统计的自定义维度2的名称，如浏览页面的用户名称
                      "cm1": "1aa" //需统计的自定义指标的数值，如用户个数为1
                    }
                  });
                },
                child: Text('页面事件'),
              ),
              RaisedButton(
                key: Key("key3"),
                onPressed: () {
                  MzanalyticsMybmw.trackEvent({
                    "ec": "领取奖励",
                    "ea": "Click",
                    "el": "任务箱领取奖励",
                    "ev": "10",
                    "CustomDimMetrics": {
                      "cd3": "首次登陆任务箱", //需统计的自定义维度名称，如任务箱名称
                      "cm2": "2" //需统计的自定义指标数值，如打开的任务箱个数，共2个
                    }
                  });
                },
                child: Text('自定义事件监测'),
              ),
              RaisedButton(
                key: Key("key4"),
                onPressed: () {
                  MzanalyticsMybmw.trackSiteCustomEvent({
                    "CustomEvent": {
                      "caid": "1",
                      "cal1": "2020/01/10",
                      "cal2": "北京",
                      "cav21": "21"
                    },
                    "CustomDimMetrics": {
                      "cd1": "ID88888", //需统计的自定义维度，如触发注册事件的用户Id
                      "cm1": "1" //需统计的自定义指标，如触发高级事件的用户数1
                    }
                  });
                },
                child: Text('高级自定义事件'),
              ),
              RaisedButton(
                key: Key("key5"),
                onPressed: () {
                  MzanalyticsMybmw.trackPulse();
                },
                child: Text('心跳事件'),
              ),
              RaisedButton(
                key: Key("key6"),
                onPressed: () {
                  getcid();
                },
                child: Text('cid: $_cid\n'),
              ),
              RaisedButton(
                key: Key("key8"),
                onPressed: () {
                  MzanalyticsMybmw.setCd("cd2", "ID12930");
                },
                child: Text("设置cd"),
              ),
              RaisedButton(
                key: Key("key9"),
                onPressed: () {
                  MzanalyticsMybmw.setCm("cm2", "1001");
                },
                child: Text("设置cm"),
              ),
              RaisedButton(
                key: Key("key10"),
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cd2");
                },
                child: Text("删除cd"),
              ),
              RaisedButton(
                key: Key("key11"),
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cm2");
                },
                child: Text("删除cm"),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> mzanalytics_mybmw-0.3.8.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';

import 'package:mzanalytics_mybmw/mzanalytics_mybmw.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _cid = 'Unknown';
  String _oaid = 'Unknown';
  String _myevent = '自定义事件';

  @override
  void initState() {
    super.initState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.

  void getcid() async {
    // callback function

    String cid = await MzanalyticsMybmw.getCid();

    setState(() {
      _cid = cid;
    });
  }

  @override
  Widget build(BuildContext context) {
    MzanalyticsMybmw.logEnabled(true);
    return MaterialApp(
      // navigatorObservers: [MZNavigationHistoryObserver()],
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Container(
          padding: EdgeInsets.all(10.0),
          child: Column(
            children: <Widget>[
              RaisedButton(
                key: Key("key1"),
                onPressed: () {
                  MzanalyticsMybmw.appid("2814");
                },
                child: Text('初始化'),
              ),
              RaisedButton(
                key: Key("key2"),
                onPressed: () {
                  MzanalyticsMybmw.trackPageView({
                    "dt": "首页",
                    "CustomDimMetrics": {
                      "cd1": "ID88888", //需统计的自定义维度1的名称，如浏览该页面的用户Id
                      "cd2": "小明机器人", //需统计的自定义维度2的名称，如浏览页面的用户名称
                      "cm1": "1" //需统计的自定义指标的数值，如用户个数为1
                    }
                  });
                },
                child: Text('页面事件'),
              ),
              RaisedButton(
                key: Key("key3"),
                onPressed: () {
                  MzanalyticsMybmw.trackEvent({
                    "ec": "领取奖励",
                    "ea": "Click",
                    "el": "任务箱领取奖励",
                    "ev": "10",
                    "CustomDimMetrics": {
                      "cd3": "首次登陆任务箱", //需统计的自定义维度名称，如任务箱名称
                      "cm2": "2" //需统计的自定义指标数值，如打开的任务箱个数，共2个
                    }
                  });
                },
                child: Text('自定义事件监测'),
              ),
              RaisedButton(
                key: Key("key4"),
                onPressed: () {
                  MzanalyticsMybmw.trackSiteCustomEvent({
                    "CustomEvent": {
                      "caid": "1",
                      "cal1": "a",
                      "cal2": "北京",
                      "cav21": "21",
                      'cal21': '21',
                    },
                    "CustomDimMetrics": {
                      "cd1": "ID88888", //需统计的自定义维度，如触发注册事件的用户Id
                      "cm1": "1" //需统计的自定义指标，如触发高级事件的用户数1
                    }
                  });
                },
                child: Text('高级自定义事件'),
              ),
              RaisedButton(
                key: Key("key5"),
                onPressed: () {
                  MzanalyticsMybmw.trackPulse();
                },
                child: Text('心跳事件'),
              ),
              RaisedButton(
                key: Key("key6"),
                onPressed: () {
                  getcid();
                },
                child: Text('cid: $_cid\n'),
              ),
              RaisedButton(
                key: Key("key8"),
                onPressed: () {
                  MzanalyticsMybmw.setCd("cd2", "ID12930");
                },
                child: Text("设置cd"),
              ),
              RaisedButton(
                key: Key("key9"),
                onPressed: () {
                  MzanalyticsMybmw.setCm("cm2", "1001");
                },
                child: Text("设置cm"),
              ),
              RaisedButton(
                key: Key("key10"),
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cd2");
                },
                child: Text("删除cd"),
              ),
              RaisedButton(
                key: Key("key11"),
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cm2");
                },
                child: Text("删除cm"),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
